library time_text_form_field;

import 'package:flutter/material.dart';

class TimeTextFormField extends StatefulWidget {
  final InputDecoration decoration;
  final String labelText;
  final TimeOfDay value;
  final Function(TimeOfDay value) onChanged;
  final Function(String) validator;

  const TimeTextFormField(
      {Key key,
      this.decoration,
      @required this.labelText,
      @required this.value,
      @required this.onChanged,
      this.validator})
      : super(key: key);

  @override
  _TimeTextFormFieldState createState() => _TimeTextFormFieldState();
}

class _TimeTextFormFieldState extends State<TimeTextFormField> {
  TextEditingController _controller = TextEditingController();
  InputDecoration _decoration;
  TimeOfDay _value;

  @override
  void initState() {
    _decoration = widget.decoration ??
        InputDecoration(
          labelText: widget.labelText,
        );
    _value = widget.value ?? TimeOfDay.now();
    super.initState();
  }

  @override
  Widget build(BuildContext context) {
    final sHour = _value.hour.toString().padLeft(2, '0');
    final sMinute = _value.minute.toString().padLeft(2, '0');

    _controller.text = '$sHour:$sMinute';

    return TextFormField(
      controller: _controller,
      decoration: _decoration,
      readOnly: true,
      onTap: () async {
        var result = await showTimePicker(
          context: context,
          initialTime: _value,
        );

        if (result != null) {
          setState(() => _value = result);
          widget.onChanged(result);
        }
      },
      validator: widget.validator,
    );
  }
}
